"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@heroku-cli/command");
const cli_ux_1 = require("cli-ux");
class Table extends command_1.Command {
    async run() {
        const { flags } = this.parse(Table);
        let endpoint = '/apps';
        if (flags.team) {
            endpoint = `/teams/${flags.team}/apps`;
        }
        else if (flags.owned) {
            endpoint = '/users/~/apps';
        }
        let { body: apps } = await this.heroku.get(endpoint);
        let columns = {
            name: {
                header: 'App Name'
            },
            stack: {
                header: 'Stack',
                get: (row) => row.stack && row.stack.name,
            },
            team: {
                header: 'Team',
                get: (row) => row.team && row.team.name,
                extended: false,
            },
            owner: {
                header: 'Owner',
                get: (row) => row.owner && row.owner.email,
                extended: true,
            },
            region: {
                header: 'Region',
                get: (row) => row.region && row.region.name,
                extended: true,
            },
            space: {
                header: 'Space',
                get: (row) => row.space && row.space.name,
                extended: true,
            },
        };
        if (flags.owned) {
            columns.owner.extended = false;
            columns.team.extended = true;
        }
        cli_ux_1.default.table(apps, columns, Object.assign({ printLine: this.log }, flags));
    }
}
Table.description = 'list apps in a custom table';
Table.examples = [
    '$ heroku apps:table',
    '$ heroku apps:table --owned',
    '$ heroku apps:table --team=my-team',
    "$ heroku apps:table --team=my-team --columns='app name,stack,region'",
    "$ heroku apps:table --team=my-team --sort='app name'",
    "$ heroku apps:table --team=my-team --filter='stack=heroku-16'",
    '$ heroku apps:table --team=my-team --csv',
];
Table.flags = Object.assign({ team: command_1.flags.team(), owned: command_1.flags.boolean({ char: 'o', description: 'only display owned apps' }) }, cli_ux_1.default.table.flags());
exports.default = Table;
